@@ -1,17 +1,7 @@
-/***************************************************************************
-
-    Copyright 2007 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "vocabularymodel.h"
 
 #include "parleydocument.h"
@@ -23,7 +13,6 @@
 
 #include "vocabularymimedata.h"
 
-#include <KEduVocExpression>
 #include <KLocalizedString>
 #include <QDebug>
 #include <KMessageBox>
