@@ -1,23 +1,14 @@
-/***************************************************************************
-    Copyright 2008 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
-    Copyright 2011 Jan Gerrit Marker <jangerrit@weiler-marker.com>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
+    SPDX-FileCopyrightText: 2011 Jan Gerrit Marker <jangerrit@weiler-marker.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "declensionwidget.h"
 
 #include <KEduVocDocument>
 #include <KEduVocExpression>
 #include <KEduVocWordtype>
-#include <KEduVocDeclension>
 
 #include <KMessageBox>
 #include <KLocalizedString>
