@@ -1,17 +1,7 @@
-/***************************************************************************
-
-    Copyright 2007 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef PARLEYDOCUMENT_H
 #define PARLEYDOCUMENT_H
 
@@ -58,8 +48,6 @@ public slots:
     void openGHNS();
     /** download new vocabularies */
     void slotGHNS();
-    /** upload the current file */
-    void uploadFile();
 
     /** Opens the given url, displays an error message and returns false on failure */
     bool open(const QUrl &);
