@@ -1,27 +1,11 @@
-/***************************************************************************
-
-                      main part of parley
-
-    -----------------------------------------------------------------------
-
-    begin         : Thu Mar 11 20:50:53 MET 1999
-
-    copyright     : (C) 1999-2001 Ewald Arnold <kvoctrain@ewald-arnold.de>
-                    (C) 2004-2007 Peter Hedlund <peter.hedlund@kdemail.net>
-                    (C) 2007-2008 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
-                    (C) 2008 Daniel Laidig <d.laidig@gmx.de>
-    -----------------------------------------------------------------------
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    main part of parley
+    SPDX-FileCopyrightText: 1999-2001 Ewald Arnold <kvoctrain@ewald-arnold.de>
+    SPDX-FileCopyrightText: 2004-2007 Peter Hedlund <peter.hedlund@kdemail.net>
+    SPDX-FileCopyrightText: 2007-2008 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
+    SPDX-FileCopyrightText: 2008 Daniel Laidig <d.laidig@gmx.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "parleymainwindow.h"
 
@@ -43,7 +27,6 @@
 #include <KMessageBox>
 #include <KTipDialog>
 #include <KXMLGUIFactory>
-#include <KXmlGuiWindow>
 #include <KToolBar>
 #include <QMenuBar>
 
