@@ -1,17 +1,7 @@
-/***************************************************************************
-
-    Copyright 2008 Avgoustinos Kadis <avgoustinos.kadis@kdemail.net>
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Avgoustinos Kadis <avgoustinos.kadis@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "scriptdialog.h"
 
 #include "scripting/parley.h"
@@ -21,7 +11,6 @@
 #include <KSharedConfig>
 #include <KConfigGroup>
 
-#include <QDialog>
 #include <QDialogButtonBox>
 #include <QVBoxLayout>
 
